@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 #ifdef HAVE_CONFIG_H
@@ -50,6 +50,9 @@ init_gio(void)
     m = Py_InitModule("gio._gio", pygio_functions);
     d = PyModule_GetDict(m);
 
+    g_type_init();
+    pyglib_init();
+
     init_pygobject_check(2, 15, 2);
 
     pygio_register_classes(d);
