@@ -185,12 +185,8 @@ pyg_boxed_new(GType boxed_type, gpointer boxed, gboolean copy_boxed,
 
     tp = g_type_get_qdata(boxed_type, pygboxed_type_key);
 
-    if (tp == NULL) {
+    if (!tp)
         tp = (PyTypeObject *)pygi_type_import_by_g_type(boxed_type);
-        if (tp == NULL) {
-            PyErr_Clear();
-        }
-    }
 
     if (!tp)
 	tp = (PyTypeObject *)&PyGBoxed_Type; /* fallback */
