@@ -142,10 +142,18 @@ pygobject_sink(GObject *obj)
 	    if (g_type_is_a(G_OBJECT_TYPE(obj),
 			    g_array_index(sink_funcs, SinkFunc, i).type)) {
 		g_array_index(sink_funcs, SinkFunc, i).sinkfunc(obj);
-		break;
+		return;
 	    }
 	}
     }
+    if (G_IS_INITIALLY_UNOWNED(obj) && !g_object_is_floating(obj)) {
+        /* GtkWindow and GtkInvisible does not return a ref to caller of
+         * g_object_new.
+         */
+        g_object_ref(obj);
+    } else if (g_object_is_floating(obj)) {
+        g_object_ref_sink(obj);
+    }
 }
 
 /**
@@ -160,12 +168,17 @@ pygobject_sink(GObject *obj)
  *
  * The sinkfunc should be able to remove the floating reference on
  * instances of the given type, or any subclasses.
+ *
+ * Deprecated: Since 2.22, sinkfuncs are not needed.
  */
 void
 pygobject_register_sinkfunc(GType type, void (* sinkfunc)(GObject *object))
 {
     SinkFunc sf;
 
+    g_message ("pygobject_register_sinkfunc is deprecated (%s)",
+               g_type_name(type));
+
 #if 0
     g_return_if_fail(G_TYPE_IS_OBJECT(type));
 #endif
@@ -294,7 +307,9 @@ PyGProps_getattro(PyGProps *self, PyObject *attr)
     }
     
     g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
+    pyg_begin_allow_threads;
     g_object_get_property(self->pygobject->obj, attr_name, &value);
+    pyg_end_allow_threads;
     ret = pyg_param_gvalue_as_pyobject(&value, TRUE, pspec);
     g_value_unset(&value);
     
@@ -590,27 +605,24 @@ pygobject_switch_to_toggle_ref(PyGObject *self)
  * In the constructor of PyGTK wrappers, this function should be
  * called after setting the obj member.  It will tie the wrapper
  * instance to the GObject so that the same wrapper instance will
- * always be used for this GObject instance.  It may also sink any
- * floating references on the GObject.
+ * always be used for this GObject instance.
  */
-static inline void
-pygobject_register_wrapper_full(PyGObject *self, gboolean sink)
-{
-    GObject *obj = self->obj;
-
-    if (sink)
-        pygobject_sink(obj);
-    g_assert(obj->ref_count >= 1);
-      /* save wrapper pointer so we can access it later */
-    g_object_set_qdata_full(obj, pygobject_wrapper_key, self, NULL);
-    if (self->inst_dict)
-        pygobject_switch_to_toggle_ref(self);
-}
-
 void
 pygobject_register_wrapper(PyObject *self)
 {
-    pygobject_register_wrapper_full((PyGObject *)self, TRUE);
+    PyGObject *gself;
+
+    g_return_if_fail(self != NULL);
+    g_return_if_fail(PyObject_TypeCheck(self, &PyGObject_Type));
+
+    gself = (PyGObject *)self;
+
+    pygobject_sink(gself->obj);
+    g_assert(gself->obj->ref_count >= 1);
+      /* save wrapper pointer so we can access it later */
+    g_object_set_qdata_full(gself->obj, pygobject_wrapper_key, gself, NULL);
+    if (gself->inst_dict)
+        pygobject_switch_to_toggle_ref(gself);
 }
 
 static PyObject *
@@ -874,12 +886,8 @@ pygobject_lookup_class(GType gtype)
     if (py_type == NULL) {
 	py_type = g_type_get_qdata(gtype, pyginterface_type_key);
 
-    if (py_type == NULL) {
+    if (py_type == NULL)
         py_type = (PyTypeObject *)pygi_type_import_by_g_type(gtype);
-        if (py_type == NULL) {
-            PyErr_Clear();
-        }
-    }
 
 	if (py_type == NULL) {
 	    py_type = pygobject_new_with_interfaces(gtype);
@@ -893,7 +901,7 @@ pygobject_lookup_class(GType gtype)
 /**
  * pygobject_new_full:
  * @obj: a GObject instance.
- * @sink: whether to sink any floating reference found on the GObject.
+ * @sink: whether to sink any floating reference found on the GObject. DEPRECATED.
  * @g_class: the GObjectClass
  *
  * This function gets a reference to a wrapper for the given GObject
@@ -943,7 +951,7 @@ pygobject_new_full(GObject *obj, gboolean sink, gpointer g_class)
 	self->private_flags.flags = 0;
 	self->obj = obj;
 	g_object_ref(obj);
-	pygobject_register_wrapper_full(self, sink);
+	pygobject_register_wrapper((PyObject *)self);
 	PyObject_GC_Track((PyObject *)self);
     }
 
@@ -1078,8 +1086,11 @@ pygobject_clear(PyGObject *self)
         if (self->inst_dict) {
             g_object_remove_toggle_ref(self->obj, pyg_toggle_notify, self);
             self->private_flags.flags &= ~PYGOBJECT_USING_TOGGLE_REF;
-        } else
+        } else {
+            pyg_begin_allow_threads;
             g_object_unref(self->obj);
+            pyg_end_allow_threads;
+        }
         self->obj = NULL;
     }
     Py_CLEAR(self->inst_dict);
@@ -1209,7 +1220,9 @@ pygobject_get_property(PyGObject *self, PyObject *args)
 	return NULL;
     }
     g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
+    pyg_begin_allow_threads;
     g_object_get_property(self->obj, param_name, &value);
+    pyg_end_allow_threads;
     ret = pyg_param_gvalue_as_pyobject(&value, TRUE, pspec);
     g_value_unset(&value);
     return ret;
@@ -1259,7 +1272,9 @@ pygobject_get_properties(PyGObject *self, PyObject *args)
         }
         g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
 
+        pyg_begin_allow_threads;
         g_object_get_property(self->obj, property_name, &value);
+        pyg_end_allow_threads;
 
         item = pyg_value_as_pyobject(&value, TRUE);
         PyTuple_SetItem(tuple, i, item);
