@@ -1,17 +1,13 @@
 import unittest
 
-import testmodule
 from common import gobject, testhelper
-from gobject import GObject, GInterface
 
 GUnknown = gobject.type_from_name("TestUnknown")
 Unknown = GUnknown.pytype
 
+
 class MyUnknown(Unknown, testhelper.Interface):
-    __gproperties__ = {
-        'some-property': (str, 'blurb', 'description',  'default',
-                          gobject.PARAM_READWRITE),
-    }
+    some_property = gobject.property(type=str)
 
     def __init__(self):
         Unknown.__init__(self)
@@ -20,22 +16,18 @@ class MyUnknown(Unknown, testhelper.Interface):
     def do_iface_method(self):
         self.called = True
         Unknown.do_iface_method(self)
-
 gobject.type_register(MyUnknown)
 
+
 class MyObject(gobject.GObject, testhelper.Interface):
-    __gproperties__ = {
-        'some-property': (str, 'blurb', 'description',  'default',
-                          gobject.PARAM_READWRITE),
-    }
+    some_property = gobject.property(type=str)
 
     def __init__(self):
-        GObject.__init__(self)
+        gobject.GObject.__init__(self)
         self.called = False
 
     def do_iface_method(self):
         self.called = True
-
 gobject.type_register(MyObject)
 
 
