@@ -85,6 +85,9 @@ class TestProperties(unittest.TestCase):
         obj.props.uint64 = 1
         self.assertEqual(obj.props.uint64, 1L)
 
+        self.assertRaises((TypeError, OverflowError), obj.set_property, "uint64", -1L)
+        self.assertRaises((TypeError, OverflowError), obj.set_property, "uint64", -1)
+
     def testUInt64DefaultValue(self):
         try:
             class TimeControl(GObject):
@@ -363,5 +366,11 @@ class TestProperty(unittest.TestCase):
         else:
             raise AssertionError
 
+    # Bug 587637.
+    def test_float_min(self):
+        gobject.property(type=float, minimum=-1)
+        gobject.property(type=gobject.TYPE_FLOAT, minimum=-1)
+        gobject.property(type=gobject.TYPE_DOUBLE, minimum=-1)
+
 if __name__ == '__main__':
     unittest.main()
